Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(623)

Unified Diff: chrome/android/java/src/org/chromium/chrome/browser/payments/PaymentApp.java

Issue 2434333005: Introduce method data map in getInstrument (Closed)
Patch Set: Fix compilation Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/java/src/org/chromium/chrome/browser/payments/PaymentApp.java
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/payments/PaymentApp.java b/chrome/android/java/src/org/chromium/chrome/browser/payments/PaymentApp.java
index d4be8f616ed9060dc493c8a8244415fffc763875..bc76fa80a8248014a16cd5b178cc37d3037fbb76 100644
--- a/chrome/android/java/src/org/chromium/chrome/browser/payments/PaymentApp.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/payments/PaymentApp.java
@@ -7,6 +7,7 @@ package org.chromium.chrome.browser.payments;
import org.json.JSONObject;
import java.util.List;
+import java.util.Map;
import java.util.Set;
/**
@@ -32,11 +33,12 @@ public interface PaymentApp {
* cards for the current profile. Can return null or empty list, e.g., if user has no locally
* stored credit cards.
*
* @param details The payment-method specific data, e.g., whether the app should be invoked in
* test or production mode, merchant identifier, or a public key.
* @param callback The object that will receive the list of instruments.
*/
- void getInstruments(JSONObject details, InstrumentsCallback callback);
+ void getInstruments(Map<String, JSONObject> methodData, InstrumentsCallback callback);
/**
* Returns a list of all payment method names that this app supports. For example, ["visa",
@@ -45,7 +47,7 @@ public interface PaymentApp {
*
* @return The list of all payment method names that this app supports.
*/
- Set<String> getSupportedMethodNames();
+ Set<String> getAppMethodNames();
/**
* Returns the identifier for this payment app to be saved in user preferences. For example,
@@ -53,5 +55,5 @@ public interface PaymentApp {
*
* @return The identifier for this payment app.
*/
- String getIdentifier();
+ String getAppIdentifier();
}

Powered by Google App Engine
@@ -32,11 +33,12 @@ public interface PaymentApp {
* stored credit cards.
*
- * @param details The payment-method specific data, e.g., whether the app should be invoked in
- * test or production mode, merchant identifier, or a public key.
- * @param callback The object that will receive the list of instruments.
+ * @param methodData The map from methods to method specific data. The data contains such
+ * information as whether the app should be invoked in test or production
+ * mode, merchant identifier, or a public key.
+ * @param callback The object that will receive the list of instruments.
*/
This is Rietveld 408576698